# chitChat Package

A Python Chat Server Package.

To run the server from the command line:
`python chitChat_package.server.py`

To run a client from the command line:
`python chitChat_package.client.py`